changeset 499:2d6d298b64f3

Remerged
author Sebastien Decugis <sdecugis@nict.go.jp>
date Tue, 17 Aug 2010 15:05:12 +0900
parents 753c9ed8f19a (current diff) 715dd6714ce7 (diff)
children d4fc98a3b79c
files
diffstat 8 files changed, 18 insertions(+), 11 deletions(-) [+]
line wrap: on
line diff
--- a/contrib/debian/freediameter-radius-gateway.install	Tue Aug 17 15:04:50 2010 +0900
+++ b/contrib/debian/freediameter-radius-gateway.install	Tue Aug 17 15:05:12 2010 +0900
@@ -1,2 +1,3 @@
 usr/lib/freeDiameter/app_radgw.fdx
 usr/lib/freeDiameter/*.rgwx
+usr/lib/rgw_common.*
--- a/extensions/CMakeLists.txt	Tue Aug 17 15:04:50 2010 +0900
+++ b/extensions/CMakeLists.txt	Tue Aug 17 15:05:12 2010 +0900
@@ -14,7 +14,7 @@
 
 # The extensions include the headers of freeDiameter that contains gnutls objects
 FIND_PACKAGE(GnuTLS REQUIRED)
-INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIRS})
+INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIR})
 find_path(GCRYPT_INCLUDE_DIR NAMES gcrypt.h)
 If ( NOT GCRYPT_INCLUDE_DIR )
 	MESSAGE(SEND_ERROR "Unable to find gcrypt.h, please install libgcrypt-dev or equivalent")
--- a/extensions/app_radgw/CMakeLists.txt	Tue Aug 17 15:04:50 2010 +0900
+++ b/extensions/app_radgw/CMakeLists.txt	Tue Aug 17 15:05:12 2010 +0900
@@ -29,6 +29,7 @@
 	hostap_compat.h
 )
 ADD_LIBRARY(rgw_common SHARED ${RG_COMMON_SRC})
+SET_TARGET_PROPERTIES(rgw_common PROPERTIES PREFIX "" )
 
 
 
@@ -124,5 +125,9 @@
 INSTALL(TARGETS app_radgw
 	LIBRARY DESTINATION ${INSTALL_EXTENSIONS_SUFFIX}
 	COMPONENT freeDiameter-radius-gateway)
+	
+INSTALL(TARGETS rgw_common
+	LIBRARY DESTINATION ${INSTALL_LIBRARY_SUFFIX}
+	COMPONENT freeDiameter-radius-gateway)
 
 # Note that all compiled plugins are added by the RGWX_ADD_PLUGIN macro in the component freeDiameter-radius-gateway as well.
--- a/freeDiameter/CMakeLists.txt	Tue Aug 17 15:04:50 2010 +0900
+++ b/freeDiameter/CMakeLists.txt	Tue Aug 17 15:05:12 2010 +0900
@@ -50,7 +50,7 @@
 
 # Require GNU TLS for building the daemon
 FIND_PACKAGE(GnuTLS REQUIRED)
-INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIRS})
+INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIR})
 SET(FD_LIBS ${FD_LIBS} ${GNUTLS_LIBRARIES})
 find_path(GCRYPT_INCLUDE_DIR NAMES gcrypt.h)
 If ( NOT GCRYPT_INCLUDE_DIR )
--- a/include/freeDiameter/CMakeLists.txt	Tue Aug 17 15:04:50 2010 +0900
+++ b/include/freeDiameter/CMakeLists.txt	Tue Aug 17 15:05:12 2010 +0900
@@ -79,7 +79,7 @@
 	CHECK_FUNCTION_EXISTS(sctp_connectx HAVE_NATIVE_SCTP)
 	IF(NOT HAVE_NATIVE_SCTP)
 		FIND_PACKAGE(SCTP REQUIRED)
-		INCLUDE_DIRECTORIES(${SCTP_INCLUDE_DIRS})
+		INCLUDE_DIRECTORIES(${SCTP_INCLUDE_DIR})
 	ENDIF(NOT HAVE_NATIVE_SCTP)
 	# Now check the number of args of this function, since it changed between Ubuntu 9.04 and 9.10
    	SET(CHECK_SCTP_CONNECTX_4_ARGS_SOURCE_CODE "
@@ -89,6 +89,7 @@
 		   return sctp_connectx(0, NULL, 0, NULL);
 		}
 		")
+	SET(CMAKE_REQUIRED_INCLUDES ${SCTP_INCLUDE_DIR})
 	SET(CMAKE_REQUIRED_LIBRARIES ${SCTP_LIBRARIES})
 	CHECK_C_SOURCE_COMPILES("${CHECK_SCTP_CONNECTX_4_ARGS_SOURCE_CODE}" SCTP_CONNECTX_4_ARGS)
 ELSE (NOT DISABLE_SCTP)
"Welcome to our mercurial repository"
--- a/cmake/Modules/FindGnuTLS.cmake	Tue Aug 17 15:04:50 2010 +0900
+++ b/cmake/Modules/FindGnuTLS.cmake	Tue Aug 17 15:05:12 2010 +0900
@@ -2,12 +2,12 @@
 # Find the native GNUTLS includes and library
 #
 #  GNUTLS_FOUND - True if gnutls found.
 #  GNUTLS_INCLUDE_DIRS - where to find gnutls.h, etc.
 #  GNUTLS_LIBRARIES - List of libraries when using gnutls.
 
-if (GNUTLS_INCLUDE_DIRS AND GNUTLS_LIBRARIES)
+if (GNUTLS_INCLUDE_DIR AND GNUTLS_LIBRARIES)
   set(GNUTLS_FIND_QUIETLY TRUE)
-endif (GNUTLS_INCLUDE_DIRS AND GNUTLS_LIBRARIES)
+endif (GNUTLS_INCLUDE_DIR AND GNUTLS_LIBRARIES)
 
 # Include dir
 find_path(GNUTLS_INCLUDE_DIR
@@ -2,12 +2,12 @@
 #
 #  GNUTLS_FOUND - True if gnutls found.
-#  GNUTLS_INCLUDE_DIRS - where to find gnutls.h, etc.
+#  GNUTLS_INCLUDE_DIR - where to find gnutls.h, etc.
 #  GNUTLS_LIBRARIES - List of libraries when using gnutls.
 
--- a/cmake/Modules/FindSCTP.cmake	Tue Aug 17 15:04:50 2010 +0900
+++ b/cmake/Modules/FindSCTP.cmake	Tue Aug 17 15:05:12 2010 +0900
@@ -2,12 +2,12 @@
 # Once done, this will define
 #
 #  SCTP_FOUND - system has SCTP
 #  SCTP_INCLUDE_DIRS - the SCTP include directories
 #  SCTP_LIBRARIES - link these to use SCTP
 
-if (SCTP_INCLUDE_DIRS AND SCTP_LIBRARIES)
+if (SCTP_INCLUDE_DIR AND SCTP_LIBRARIES)
   set(SCTP_FIND_QUIETLY TRUE)
-endif (SCTP_INCLUDE_DIRS AND SCTP_LIBRARIES)
+endif (SCTP_INCLUDE_DIR AND SCTP_LIBRARIES)
 
 # Include dir
 find_path(SCTP_INCLUDE_DIR
@@ -2,12 +2,12 @@
 #
 #  SCTP_FOUND - system has SCTP
-#  SCTP_INCLUDE_DIRS - the SCTP include directories
+#  SCTP_INCLUDE_DIR - the SCTP include directories
 #  SCTP_LIBRARIES - link these to use SCTP
 
--- a/freeDiameter/tests/testfifo.c	Tue Aug 17 15:04:50 2010 +0900
+++ b/freeDiameter/tests/testfifo.c	Tue Aug 17 15:05:12 2010 +0900
@@ -211,7 +211,7 @@
 		
 		/* Initialize the ts */
 		CHECK(0, clock_gettime(CLOCK_REALTIME, &ts));
-		ts.tv_sec += 2; /* Set the timeout to 2 second */
+		ts.tv_sec += 20; /* Set the timeout to 20 second */
 		
 		/* Create the messages */
 		CHECK( 0, fd_dict_search ( fd_g_config->cnf_dict, DICT_COMMAND, CMD_BY_NAME, "Device-Watchdog-Request",		&dwr_model, ENOENT ) );
@@ -281,7 +281,7 @@
 		
 		/* Initialize the ts */
 		CHECK(0, clock_gettime(CLOCK_REALTIME, &ts));
-		ts.tv_sec += 2; /* Set the timeout to 2 second */
+		ts.tv_sec += 10; /* Set the timeout to 10 second */
 		
 		/* Initialize the test data structures */
 		td.queue = queue;